@@ -1,6 +1,6 @@
 # -*- Mode: Python; coding: utf-8; indent-tabs-mode: nil; tab-width: 4 -*-
 ### BEGIN LICENSE
-# Copyright (C) 2011-2012 Marc Deslauriers <marc.deslauriers@canonical.com>
+# Copyright (C) 2011-2013 Marc Deslauriers <marc.deslauriers@canonical.com>
 # This program is free software: you can redistribute it and/or modify it
 # under the terms of the GNU General Public License version 3, as published
 # by the Free Software Foundation.
@@ -18,34 +18,13 @@
 import logging
 import os
 
-from gi.repository import Gtk
-
 from . pasaffeconfig import get_data_file
-from . Builder import Builder
 
 import gettext
 from gettext import gettext as _
 gettext.textdomain('pasaffe')
 
 
-def get_builder(builder_file_name):
-    """Return a fully-instantiated Gtk.Builder instance from specified ui
-    file
-
-    :param builder_file_name: The name of the builder file, without extension.
-        Assumed to be in the 'ui' directory under the data path.
-    """
-    # Look for the ui file that describes the user interface.
-    ui_filename = get_data_file('ui', '%s.ui' % (builder_file_name,))
-    if not os.path.exists(ui_filename):
-        ui_filename = None
-
-    builder = Builder()
-    builder.set_translation_domain('pasaffe')
-    builder.add_from_file(ui_filename)
-    return builder
-
-
 # Owais Lone : To get quick access to icons and stuff.
 def get_media_file(media_file_name):
     media_filename = get_data_file('media', '%s' % (media_file_name,))
@@ -103,11 +82,6 @@ def get_help_uri(page=None):
     return help_uri
 
 
-def show_uri(parent, link):
-    screen = parent.get_screen()
-    Gtk.show_uri(screen, link, Gtk.get_current_event_time())
-
-
 def alias(alternative_function_name):
     '''see http://www.drdobbs.com/web-development/184406073#l9'''
     def decorator(function):
